==> haskell-mono-traversable-1.0.20.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.20.0
visibility:           public
id:                   mono-traversable-1.0.20.0-GtWxG74scQa8pD7SbED1dv
key:                  mono-traversable-1.0.20.0-GtWxG74scQa8pD7SbED1dv
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  a10c25c054e8186fbdd8d8a94d638127
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.20.0-GtWxG74scQa8pD7SbED1dv
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X
    vector-algorithms-0.9.0.2-IlDfaN1LnLS9CyaBdM7Bl0

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.20.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.20.0
visibility:           public
id:                   mono-traversable-1.0.20.0-ItDdnlVur97L9CuLOjIpaO
key:                  mono-traversable-1.0.20.0-ItDdnlVur97L9CuLOjIpaO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  00dbb805e520574685506da6b7c5df95
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.20.0-ItDdnlVur97L9CuLOjIpaO
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-9qtKP8IRTHnKAJSp2mdpwo
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X
    vector-algorithms-0.9.0.2-7hI43aFVNzx3PLprLeqgEZ

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
